# IBM Guardium integration 
Paul Shmakov, last reviewed: July 2018.

This document describes components of IBM Guardium Activity Monitor, deployment, and configuration.

## Software Requirements 
- x64 Windows 2008 R2 and above
- .NET 4.5
- Visual C++ 120 runtime (Microsoft_VC120_CRT_x64)
- (only for EMC monitoring) EMC CEE 

## Software Components

The product consists of the following components:
- UI console
- Agent service
- Monitoring services (NetApp, EMC, Hitachi, Nasuni, SharePoint)
- Logging service

|Component|File|Service name|Description|
|---------|----|------------|-----------|
|UI console|Configuration.exe| |Provides UI, manages the Agent service.|
|Agent service|ConfigurationAgent.exe|IBMActivityMonitorAgentSvc|Manages the monitoring services. Registers and starts when they are needed, stops and unregisters otherwise. It provides API for the UI console.|
|NetApp monitoring service|FPolicyServerSvc.exe|IBMActivityMonitorFPolicySvc|Collects activity events from 7-mode and C-mode NetApp devices|
|EMC monitoring service|CelerraServiceSvc.exe|IBMActivityMonitorEmcSvc|Collects activity events from EMC Celerra, VNX, Isilon, and Unity devices. Requires EMC CEE.|
|HNAS monitoring service|HitachiService.exe|IBMActivityMonitorHitachiSvc|Collects activity events from Hitachi NAS devices.|
|Nasuni monitoring service|MonitorService45.exe / NasuniMonitor.dll|IBMActivityMonitorNasuniSvc|Collects activity events from Nasuni devices.|
|SharePoint 2010 monitoring service|MonitorService35.exe / SharePointMonitor35.dll|IBMActivityMonitorSharePointSvc|Collects activity events from SharePoint 2010. .NET 3.5 process.|
|SharePoint 2013 monitoring service|MonitorService40.exe / SharePointMonitor40.dll|IBMActivityMonitorSharePointSvc|Collects activity events from SharePoint 2013. .NET 4.0 process.|
|SharePoint 2016 monitoring service|MonitorService45.exe / SharePointMonitor45.dll|IBMActivityMonitorSharePointSvc|Collects activity events from SharePoint 2016. .NET 4.5 process.|
|Logging service|FSACLoggingSvc.exe|IBMActivityMonitorLoggingSvc|Receives events from the monitoring services and forwards them to Syslog or log files|
|API library|ActivityMonitor.dll / ActivityMonitor.lib| |Provides API to manage the product|
|API sample|ActivityMonitorClient.exe| |Sample API client|
|Libraries|*.dll| |Various product and 3rd party libraries|

The UI Console registers and starts the Agent service if it's not present. The service is registered to start automatically. 

The UI Console talks to the Agent service via TCP port 16025 to get information about monitored hosts,
add new hosts, change configuration. The same functionality is exposed via ActivityMonitor.dll 
for programmatic access. 

The Agent service ensures the monitoring services are registered and running when they are needed. When the monitoring service is not needed anymore, the Agent service stops and unregisters it.
For instance, when a first NetApp host is added to be monitored, the Agent service registers the NetApp monitoring service
and starts it. The Agent ensures that the monitoring service is up and running with periodic checks.
When the last NetApp host is removed / disabled from being monitored, the Agent stops and unregisters the NetApp monitoring service. 

All the services execute under the Local System account, but NetApp monitoring service. 
To monitor 7-mode NetApp filers the service runs under a specified domain account. 

## Installation

All the components of the product come as a zip package. The installation procedure must keep the same folder structure.

It's recommended to create native images during installation with NGEN for `Configuration.exe` and `ConfigurationAgent.exe` to improve first start times.

The services are registered and started automatically during execution. 
The uninstallation procedure must stop and unregister the services:
- IBMActivityMonitorAgentSvc
- IBMActivityMonitorFPolicySvc
- IBMActivityMonitorEmcSvc
- IBMActivityMonitorHitachiSvc
- IBMActivityMonitorNasuniSvc
- IBMActivityMonitorSharePointSvc
- IBMActivityMonitorLoggingSvc
 
It's recommended to stop and unregister the Agent service (IBMActivityMonitorAgentSvc) first. 
Otherwise, the Agent service may interfere with the uninstallation - it may register/start monitoring services back.
The Logging service (IBMActivityMonitorLoggingSvc) should be the last one. 

The uninstallation procedure may want to want to remove the data directory and the registry key.

## Data 

Most of the product configuration, data, and logs is kept in `%ALLUSERSPROFILE%\IBM\Guardium\ActivityMonitor` directory. 
Several settings are stored in `HKEY_LOCAL_MACHINE\SOFTWARE\IBM\Guardium\ActivityMonitor` registry key.
The monitored hosts are stored in the `MonitoredHosts.ini` file. However, the configuration files should not be modified directly. 

The uninstallation procedure should remove the `Logs` subfolder. 
Whether to delete other contents of the data directory depends on the scenario. 
If it's an upgrade, all the files should be left intact to preserve configuration and state. 
If it's full uninstallation and there's no need in keeping the configuration and the monitoring state, the data folder can be deleted. 

## Customization

Available hosts in UI can be modified using an optional `Console.ini` file, located in the same folder as the binaries. 
If the file doesn't exist all hosts will be available. 

Format of the file:

```
[FEATURES]
Nasuni=ON
NetApp=ON
Celerra=ON
```

Possible parameter names:

- `Celerra`
- `Hitachi`
- `Isilon`
- `Nasuni`
- `NetApp`
- `SharePoint`
- `Unity`
- `Windows`

Possible values: `ON` or `OFF`.
Default value for hosts that are not present in the INI file is `OFF`.

## Troubleshooting

All the components of the product use the same configuration switch that specifies the tracing level. The `Info` level is recommended for normal operation. The `Trace` level is the most verbose and the most expensive, in many cases raw network packets are logged. 

Each component creates its own log file under `%ALLUSERSPROFILE%\IBM\Guardium\ActivityMonitor\Logs` directory. The log files rotate when they reach 20MB; 5 most recent files are kept. 

